@@ -14,8 +14,8 @@
 
 #include <string.h>
 #include <camel/camel-i18n.h>
-#include <camel/camel-transport.h>
 
+#include "camel-sunone-transport.h"
 #include "camel-sunone-store.h"
 
 static guint wcap_url_hash (gconstpointer key);
@@ -25,10 +25,13 @@ static gint wcap_url_equal (gconstpointer a, gconstpointer b);
 CamelProviderConfEntry wcap_conf_entries[] = {
 	/* override the labels/defaults of the standard settings */
 
-	{ CAMEL_PROVIDER_CONF_LABEL, "hostname", NULL, N_("_Server") },
 	{ CAMEL_PROVIDER_CONF_LABEL, "username", NULL, N_("_User") },
 
 	/* extra SunOne configuration settings */
+	{ CAMEL_PROVIDER_CONF_SECTION_START, "calendar", NULL, N_("Calendar") },
+	{ CAMEL_PROVIDER_CONF_ENTRY, "serverurl", NULL, N_("_Server URL:"), NULL },
+	{ CAMEL_PROVIDER_CONF_CHECKBOX, "useproxy", NULL, N_("_Use System Proxy Settings"), "1" },
+	{ CAMEL_PROVIDER_CONF_SECTION_END },
 	/* ... */
 
 	{ CAMEL_PROVIDER_CONF_END }
@@ -40,10 +43,9 @@ static CamelProvider wcap_provider = {
 	N_("Sun Calendar WCAP"),
 	N_("For accessing Sun Calendar servers"),
 	"mail",
-	CAMEL_PROVIDER_IS_REMOTE | CAMEL_PROVIDER_IS_SOURCE | 
-	CAMEL_PROVIDER_SUPPORTS_SSL ,
+	CAMEL_PROVIDER_IS_REMOTE | CAMEL_PROVIDER_IS_SOURCE,
 
-	CAMEL_URL_NEED_USER | CAMEL_URL_NEED_HOST | CAMEL_URL_NEED_PORT,
+	CAMEL_URL_NEED_USER,
 
 	wcap_conf_entries,
 
@@ -62,7 +64,7 @@ camel_provider_module_init(void)
 #endif
 
 	wcap_provider.object_types[CAMEL_PROVIDER_STORE] =  camel_sunone_store_get_type ();
-	wcap_provider.object_types[CAMEL_PROVIDER_TRANSPORT] =  camel_transport_get_type ();
+	wcap_provider.object_types[CAMEL_PROVIDER_TRANSPORT] =  camel_sunone_transport_get_type ();
 	camel_provider_register(&wcap_provider);
 
 }
